@@ -1,4 +1,3 @@
-mod build_id_calculator;
 mod chain_map;
 mod context;
 mod error;
@@ -6,8 +5,7 @@ mod global_state;
 mod module_state;
 
 use self::{
-    build_id_calculator::BuildIdCalculator, chain_map::ChainMap, context::Context,
-    global_state::GlobalState, module_state::ModuleState,
+    chain_map::ChainMap, context::Context, global_state::GlobalState, module_state::ModuleState,
 };
 pub use self::{context::ModuleDependencyMap, error::CompileError};
 use crate::{
@@ -78,7 +76,6 @@ fn compile_module(
         .modules()
         .get(path)
         .ok_or_else(|| CompileError::ModuleNotFound(path.into()))?;
-    let mut build_id_calculator = BuildIdCalculator::new(path.into());
 
     for statement in module.statements() {
         match statement {
@@ -97,7 +94,6 @@ fn compile_module(
                 );
 
                 let ir = Arc::new(Build::new(
-                    build_id_calculator.calculate(),
                     build.outputs().to_vec(),
                     build.implicit_outputs().to_vec(),
                     if build.rule() == PHONY_RULE {
@@ -234,13 +230,8 @@ mod tests {
         )
     }
 
-    fn ir_explicit_build(
-        id: impl Into<String>,
-        outputs: Vec<String>,
-        rule: Rule,
-        inputs: Vec<String>,
-    ) -> Build {
-        Build::new(id, outputs, vec![], rule.into(), inputs, vec![], None)
+    fn ir_explicit_build(outputs: Vec<String>, rule: Rule, inputs: Vec<String>) -> Build {
+        Build::new(outputs, vec![], rule.into(), inputs, vec![], None)
     }
 
     #[test]
@@ -279,13 +270,7 @@ mod tests {
             Configuration::new(
                 [(
                     "bar".into(),
-                    ir_explicit_build(
-                        "build.ninja:0",
-                        vec!["bar".into()],
-                        Rule::new("42", None),
-                        vec![]
-                    )
-                    .into()
+                    ir_explicit_build(vec!["bar".into()], Rule::new("42", None), vec![]).into()
                 )]
                 .into_iter()
                 .collect(),
@@ -317,13 +302,7 @@ mod tests {
             Configuration::new(
                 [(
                     "bar".into(),
-                    ir_explicit_build(
-                        "build.ninja:0",
-                        vec!["bar".into()],
-                        Rule::new("1 2", None),
-                        vec![]
-                    )
-                    .into()
+                    ir_explicit_build(vec!["bar".into()], Rule::new("1 2", None), vec![]).into()
                 )]
                 .into_iter()
                 .collect(),
@@ -354,13 +333,7 @@ mod tests {
             Configuration::new(
                 [(
                     "bar".into(),
-                    ir_explicit_build(
-                        "build.ninja:0",
-                        vec!["bar".into()],
-                        Rule::new("42", None),
-                        vec![]
-                    )
-                    .into()
+                    ir_explicit_build(vec!["bar".into()], Rule::new("42", None), vec![]).into()
                 )]
                 .into_iter()
                 .collect(),
@@ -390,13 +363,7 @@ mod tests {
             Configuration::new(
                 [(
                     "bar".into(),
-                    ir_explicit_build(
-                        "build.ninja:0",
-                        vec!["bar".into()],
-                        Rule::new("$", None),
-                        vec![]
-                    )
-                    .into()
+                    ir_explicit_build(vec!["bar".into()], Rule::new("$", None), vec![]).into()
                 )]
                 .into_iter()
                 .collect(),
@@ -428,7 +395,6 @@ mod tests {
                 [(
                     "bar".into(),
                     ir_explicit_build(
-                        "build.ninja:0",
                         vec!["bar".into()],
                         Rule::new("baz", None),
                         vec!["baz".into()]
@@ -473,7 +439,6 @@ mod tests {
                 [(
                     "bar".into(),
                     ir_explicit_build(
-                        "build.ninja:0",
                         vec!["bar".into()],
                         Rule::new("baz", None),
                         vec!["baz".into(), "blah".into()]
@@ -508,13 +473,7 @@ mod tests {
             Configuration::new(
                 [(
                     "bar".into(),
-                    ir_explicit_build(
-                        "build.ninja:0",
-                        vec!["bar".into()],
-                        Rule::new("bar", None),
-                        vec![]
-                    )
-                    .into()
+                    ir_explicit_build(vec!["bar".into()], Rule::new("bar", None), vec![]).into()
                 )]
                 .into_iter()
                 .collect(),
@@ -527,7 +486,6 @@ mod tests {
     #[test]
     fn interpolate_out_variable_with_implicit_output() {
         let build = Arc::new(Build::new(
-            "build.ninja:0",
             vec!["bar".into()],
             vec!["baz".into()],
             Rule::new("bar", None).into(),
@@ -600,7 +558,6 @@ mod tests {
                 [(
                     "bar".into(),
                     Build::new(
-                        "build.ninja:0",
                         vec!["bar".into()],
                         vec![],
                         Some(Rule::new("", None)),
@@ -640,23 +597,11 @@ mod tests {
                 [
                     (
                         "bar".into(),
-                        ir_explicit_build(
-                            "build.ninja:0",
-                            vec!["bar".into()],
-                            Rule::new("", None),
-                            vec![]
-                        )
-                        .into()
+                        ir_explicit_build(vec!["bar".into()], Rule::new("", None), vec![]).into()
                     ),
                     (
                         "baz".into(),
-                        ir_explicit_build(
-                            "build.ninja:1",
-                            vec!["baz".into()],
-                            Rule::new("", None),
-                            vec![]
-                        )
-                        .into()
+                        ir_explicit_build(vec!["baz".into()], Rule::new("", None), vec![]).into()
                     )
                 ]
                 .into_iter()
@@ -693,13 +638,7 @@ mod tests {
             Configuration::new(
                 [(
                     "bar".into(),
-                    ir_explicit_build(
-                        "build.ninja:0",
-                        vec!["bar".into()],
-                        Rule::new("42", None),
-                        vec![]
-                    )
-                    .into()
+                    ir_explicit_build(vec!["bar".into()], Rule::new("42", None), vec![]).into()
                 )]
                 .into_iter()
                 .collect(),
@@ -733,7 +672,6 @@ mod tests {
                 [(
                     "foo".into(),
                     Build::new(
-                        "build.ninja:0",
                         vec!["foo".into()],
                         vec![],
                         None,
@@ -793,7 +731,6 @@ mod tests {
                 [(
                     "foo".into(),
                     Build::new(
-                        "build.ninja:0",
                         vec!["foo".into()],
                         vec![],
                         None,
@@ -854,13 +791,7 @@ mod tests {
                 Configuration::new(
                     [(
                         "bar".into(),
-                        ir_explicit_build(
-                            "foo.ninja:0",
-                            vec!["bar".into()],
-                            Rule::new("42", None),
-                            vec![]
-                        )
-                        .into()
+                        ir_explicit_build(vec!["bar".into()], Rule::new("42", None), vec![]).into()
                     )]
                     .into_iter()
                     .collect(),
@@ -912,13 +843,7 @@ mod tests {
                 Configuration::new(
                     [(
                         "bar".into(),
-                        ir_explicit_build(
-                            "foo.ninja:0",
-                            vec!["bar".into()],
-                            Rule::new("42", None),
-                            vec![]
-                        )
-                        .into()
+                        ir_explicit_build(vec!["bar".into()], Rule::new("42", None), vec![]).into()
                     )]
                     .into_iter()
                     .collect(),
@@ -966,13 +891,7 @@ mod tests {
                 Configuration::new(
                     [(
                         "bar".into(),
-                        ir_explicit_build(
-                            "build.ninja:0",
-                            vec!["bar".into()],
-                            Rule::new("42", None),
-                            vec![]
-                        )
-                        .into()
+                        ir_explicit_build(vec!["bar".into()], Rule::new("42", None), vec![]).into()
                     )]
                     .into_iter()
                     .collect(),
